Module download

Module download 

Functions

download
download_and_extract_repo
Downloads a gzip archive from url, extracts it, moves the result to dest, resets the git repo, and deletes gitignored files.